/***** drawGenes.c ********************************
 * Description: 
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Thu Mar  2 14:53:17 2017
 **************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <limits.h>
#include "interface.h"
#include "eprintf.h"

void scanFile(FILE *fp, Args *args){
  int start, end, min, max;
  char strand;

  max = INT_MIN;
  min = INT_MAX;
  while(fscanf(fp,"%d\t%d\t%c", &start, &end, &strand) != EOF){
    if(strand == '+' || strand == '1')
      printf("%d\t0\n%d\t1\n%d\t1\n%d\t0\n",start,start,end,end);
    else if(strand == '-' || strand == '0')
      printf("%d\t0\n%d\t-1\n%d\t-1\n%d\t0\n",start,start,end,end);
    else{
      printf("Cannot recognize strand designation %c; please use +/- or 1/2\n", strand);
      exit(-1);
    }
    if(max < end)
      max = end;
    if(min > start)
      min = start;
  }
  if(args->s != -1)
    min = args->s;
  if(args->s != -1)
    max = args->e;
  if(max > args->e)
    args->e = max;
  printf("%d\t0\n%d\t0\n",min,max);
}

int main(int argc, char *argv[]){
  int i;
  char *version;
  Args *args;
  FILE *fp;

  version = "0.3";
  setprogname2("drawGenes");
  args = getArgs(argc, argv);
  if(args->v)
    printSplash(version);
  if(args->h || args->E)
    printUsage(version);
  if(args->numInputFiles == 0){
    fp = stdin;
    scanFile(fp, args);
  }else{
    for(i=0;i<args->numInputFiles;i++){
      fp = efopen(args->inputFiles[i],"r");
      scanFile(fp, args);
      fclose(fp);
    }
  }
  free(args);
  free(progname());
  return 0;
}

