/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  int c;
  char *optString = "hvs:e:";

  args = (Args *)emalloc(sizeof(Args));
  args->s = -1;
  args->e = -1;
  args->h = 0;
  args->v = 0;
  args->e = -1;
  args->E = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 's':                           /* start */
      args->s = atoi(optarg);
      break;
    case 'e':                           /* end */
      args->e = atoi(optarg);
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->E = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  args->inputFiles = argv + optind;
  args->numInputFiles = argc - optind;
  return args;
}


void printUsage(char *version){
  printf("Usage: %s [options] [inputFiles]\n",progname());
  printf("Given gene coordinates (start end strand), output box coordinates for drawing\n");
  printf("Example: %s coords.txt | gnuplot -p -e 'unset ytics; plot[][-10:10] \"< cat\" title \"\" with lines'\n", progname());
  printf("Options:\n");
  printf("\t[-s <NUM> start; default: minimal gene coordinate]\n");
  printf("\t[-e <NUM> end; default: maximal gene coordinate]\n");
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
